# -*- coding: utf-8 -*-
"""
Custom exceptions
"""


class BaseException(Exception):
    def __init__(self, message=""):
        self.message = message


class MissingMandatoryArgument(BaseException):
    """
    Raised when a mandatory argument is missing
    """

    pass


class InstanceNotFound(BaseException):
    """
    Raised when no instance could be found
    """

    pass


class MultipleInstanceFound(BaseException):
    """
    Raised when no instance could be found
    """

    pass



"""
Tools used to handle accounting files
"""
from typing import IO, Iterable
from zope.interface import Interface, implementer


class IAccountingOperationStreamer(Interface):
    """
    Data streamer used to stream the raw data representing operations
    """

    def stream(self) -> Iterable[dict]:
        """
        Stream dictionnaries for each operations
        """
        pass


@implementer(IAccountingOperationStreamer)
class AccountingSlkStreamer:

    def __init__(self, file_object: IO):
        self.file_object = file_object

